about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--tvix/eval/src/compiler.rs7
1 files changed, 4 insertions, 3 deletions
diff --git a/tvix/eval/src/compiler.rs b/tvix/eval/src/compiler.rs
index 7ab1dce193..cfcf78f31b 100644
--- a/tvix/eval/src/compiler.rs
+++ b/tvix/eval/src/compiler.rs
@@ -44,9 +44,10 @@ impl Compiler {
                 self.compile_string(op)
             }
 
-            // The interpolation node is just a wrapper around the
-            // inner value of a fragment, it only requires unwrapping.
-            rnix::SyntaxKind::NODE_STRING_INTERPOL => {
+            // The interpolation & dynamic nodes are just wrappers
+            // around the inner value of a fragment, they only require
+            // unwrapping.
+            rnix::SyntaxKind::NODE_STRING_INTERPOL | rnix::SyntaxKind::NODE_DYNAMIC => {
                 self.compile(node.first_child().expect("TODO (should not be possible)"))
             }